@@ -49,12 +49,15 @@ class Skybell:  # pylint:disable=too-many-instance-attributes
         self._disable_cache = disable_cache
         self._get_devices = get_devices
         self._password = password
+        if username is not None and self._cache_path == CONST.CACHE_PATH:
+            self._cache_path = f"skybell_{username.replace('.', '')}.pickle"
         self._username = username
         if session is None:
             session = ClientSession()
             self._close_session = True
         self._session = session
         self._login_sleep = login_sleep
+        self._user: dict[str, str] = {}
 
         # Create a new cache template
         self._cache: dict[str, str | dict[str, CONST.DeviceType]] = {
@@ -84,6 +87,7 @@ class Skybell:  # pylint:disable=too-many-instance-attributes
             and self._auto_login
         ):
             await self.async_login()
+        self._user = await self.async_send_request(method="get", url=CONST.USERS_ME_URL)
         return await self.async_get_devices()
 
     async def async_login(self, username: str = None, password: str = None) -> bool:
@@ -150,11 +154,11 @@ class Skybell:  # pylint:disable=too-many-instance-attributes
 
             for device_json in response:
                 # Attempt to reuse an existing device
-                device = self._devices.get(device_json["id"])
+                device = self._devices.get(device_json[CONST.ID])
 
                 # No existing device, create a new one
                 if device:
-                    await device.async_update({device_json["id"]: device_json})
+                    await device.async_update({device_json[CONST.ID]: device_json})
                 else:
                     device = SkybellDevice(device_json, self)
                     self._devices[device.device_id] = device
@@ -178,6 +182,21 @@ class Skybell:  # pylint:disable=too-many-instance-attributes
 
         return device
 
+    @property
+    def user_id(self) -> str:
+        """Return logged in user id."""
+        return self._user[CONST.ID]
+
+    @property
+    def user_first_name(self) -> str:
+        """Return logged in user first name."""
+        return self._user["firstName"]
+
+    @property
+    def user_last_name(self) -> str:
+        """Return logged in user last name."""
+        return self._user["lastName"]
+
     async def async_send_request(  # pylint:disable=too-many-arguments
         self,
         method: str,
@@ -191,13 +210,13 @@ class Skybell:  # pylint:disable=too-many-instance-attributes
             await self.async_login()
 
         headers = headers if headers else {}
-        if len(self.cache(CONST.ACCESS_TOKEN)) > 0:
-            headers["Authorization"] = f"Bearer {self.cache(CONST.ACCESS_TOKEN)}"
-
-        headers["content-type"] = "application/json"
-        headers["accept"] = "*/*"
-        headers["x-skybell-app-id"] = cast(str, self.cache(CONST.APP_ID))
-        headers["x-skybell-client-id"] = cast(str, self.cache(CONST.CLIENT_ID))
+        if "cloud.myskybell.com" in url:
+            if len(self.cache(CONST.ACCESS_TOKEN)) > 0:
+                headers["Authorization"] = f"Bearer {self.cache(CONST.ACCESS_TOKEN)}"
+            headers["content-type"] = "application/json"
+            headers["accept"] = "*/*"
+            headers["x-skybell-app-id"] = cast(str, self.cache(CONST.APP_ID))
+            headers["x-skybell-client-id"] = cast(str, self.cache(CONST.CLIENT_ID))
 
         _LOGGER.debug("HTTP %s %s Request with headers: %s", method, url, headers)
 
@@ -218,12 +237,16 @@ class Skybell:  # pylint:disable=too-many-instance-attributes
                 return await self.async_send_request(
                     method, url, headers, json_data, False
                 )
-
-            raise SkybellException(
-                self,
-                f"Request exception for '{url}' with - {exc}",
-            ) from exc
-        _result = await response.json()
+            if "cloud.myskybell.com" in url:
+                raise SkybellException(
+                    self,
+                    f"Request exception for '{url}' with - {exc}",
+                ) from exc
+            raise SkybellException(self, ("Failed getting image: %s", exc)) from exc
+        if "cloud.myskybell.com" in url:
+            _result = await response.json()
+        else:
+            _result = await response.read()
         if response.status < 400:
             return _result
         if response.status == 401:
