@@ -7,7 +7,7 @@ from distutils.util import strtobool
 from typing import TYPE_CHECKING, cast
 
 from . import utils as UTILS
-from .exceptions import SkybellException
+from .exceptions import SkybellAuthenticationException, SkybellException
 from .helpers import const as CONST
 from .helpers import errors as ERROR
 
@@ -20,9 +20,11 @@ _LOGGER = logging.getLogger(__name__)
 class SkybellDevice:  # pylint:disable=too-many-public-methods, too-many-instance-attributes
     """Class to represent each Skybell device."""
 
+    _skybell: Skybell
+
     def __init__(self, device_json: dict[str, str], skybell: Skybell) -> None:
         """Set up Skybell device."""
-        self._activities: list = []
+        self._activities: list[dict[str, str]] = []
         self._avatar_json: dict[str, str] = {}
         self._device_id = device_json.get(CONST.ID, "")
         self._device_json = device_json
@@ -30,6 +32,7 @@ class SkybellDevice:  # pylint:disable=too-many-public-methods, too-many-instanc
         self._settings_json: dict[str, str | int] = {}
         self._skybell = skybell
         self._type = device_json.get(CONST.TYPE, "")
+        self.images: dict[str, bytes] = {}
 
     async def _async_device_request(self) -> dict[str, str | dict[str, str]]:
         url = str.replace(CONST.DEVICE_URL, "$DEVID$", self.device_id)
@@ -53,7 +56,7 @@ class SkybellDevice:  # pylint:disable=too-many-public-methods, too-many-instanc
 
     async def _async_activities_request(self) -> list[dict[str, str]]:
         url = str.replace(CONST.DEVICE_ACTIVITIES_URL, "$DEVID$", self.device_id)
-        return await self._skybell.async_send_request(method="get", url=url)
+        return await self._skybell.async_send_request(method="get", url=url) or []
 
     async def async_update(  # pylint:disable=too-many-arguments
         self,
@@ -71,37 +74,61 @@ class SkybellDevice:  # pylint:disable=too-many-public-methods, too-many-instanc
             UTILS.update(self._device_json, device_json or {})
 
         if refresh or avatar_json or len(self._avatar_json) == 0:
-            self._avatar_json = await self._async_avatar_request()
+            result = await self._async_avatar_request()
+            if result[CONST.CREATED_AT] != self._avatar_json.get(CONST.CREATED_AT):
+                self.images[CONST.AVATAR] = await self._skybell.async_send_request(
+                    "get", result[CONST.URL]
+                )
+            self._avatar_json = result
             UTILS.update(self._avatar_json, avatar_json or {})
 
-        if refresh or info_json or len(self._info_json) == 0:
-            self._info_json = await self._async_info_request()
-            UTILS.update(self._info_json, info_json or {})
+        if self.acl == CONST.ACLType.OWNER.value:
+            if refresh or info_json or len(self._info_json) == 0:
+                self._info_json = await self._async_info_request()
+                UTILS.update(self._info_json, info_json or {})
 
-        if refresh or settings_json or len(self._settings_json) == 0:
-            self._settings_json = await self._async_settings_request()
-            UTILS.update(self._settings_json, settings_json or {})
+        if self.acl != CONST.ACLType.READ.value:
+            if refresh or settings_json or len(self._settings_json) == 0:
+                self._settings_json = await self._async_settings_request()
+                UTILS.update(self._settings_json, settings_json or {})
 
         if refresh:
             await self._async_update_activities()
 
     async def _async_update_activities(self) -> None:
         """Update stored activities and update caches as required."""
-        self._activities = await self._async_activities_request() or []
+        activities = await self._async_activities_request()
+        if self._activities:
+            for act in activities:
+                if act[CONST.ID] not in [x[CONST.ID] for x in self._activities]:
+                    self.images[
+                        CONST.ACTIVITY
+                    ] = await self._skybell.async_send_request(
+                        "get", act[CONST.MEDIA_URL]
+                    )
+        else:
+            await self._async_update_events(activities=activities)
+            latest = self.latest()[CONST.MEDIA_URL]
+            self.images[CONST.ACTIVITY] = await self._skybell.async_send_request(
+                "get", latest
+            )
+        self._activities = activities
         _LOGGER.debug("Device Activities Response: %s", self._activities)
 
         await self._async_update_events()
 
-    async def _async_update_events(self) -> None:
+    async def _async_update_events(
+        self, activities: list[dict[str, str]] | None = None
+    ) -> None:
         """Update our cached list of latest activity events."""
         events = cast(CONST.EventType, self._skybell.dev_cache(self, CONST.EVENT)) or {}
 
-        for activity in self._activities:
-            event = activity.get(CONST.EVENT)
-            created_at = activity.get(CONST.CREATED_AT)
+        activities = activities or self._activities
+        for activity in activities:
+            event = activity[CONST.EVENT]
+            created_at = activity[CONST.CREATED_AT]
 
-            old_event = events.get(event)
-            if old_event and created_at < old_event.get(CONST.CREATED_AT):
+            if (old := events.get(event)) and created_at < old[CONST.CREATED_AT]:
                 continue
 
             events[event] = activity
@@ -110,7 +137,7 @@ class SkybellDevice:  # pylint:disable=too-many-public-methods, too-many-instanc
 
     def activities(self, limit: int = 1, event: str = None) -> list[dict[str, str]]:
         """Return device activity information."""
-        activities = self._activities or []
+        activities = self._activities
 
         # Filter our activity array if requested
         if event:
@@ -120,12 +147,12 @@ class SkybellDevice:  # pylint:disable=too-many-public-methods, too-many-instanc
         return activities[:limit]
 
     def latest(self, event: str = None) -> dict[str, str]:
-        """Return the latest event activity."""
+        """Return the latest event activity (motion or button)."""
         events = cast(CONST.EventType, self._skybell.dev_cache(self, CONST.EVENT)) or {}
         _LOGGER.debug(events)
 
         if event:
-            return events.get(event, {})
+            return events.get(f"device:sensor:{event}", {})
 
         latest: dict[str, str] = {}
         latest_date = None
@@ -147,8 +174,7 @@ class SkybellDevice:  # pylint:disable=too-many-public-methods, too-many-instanc
             value = bool(value)
             value = CONST.MOTION_POLICY_ON if value is True else CONST.MOTION_POLICY_OFF
             await self._async_set_setting({key: value})
-        if key in [CONST.LED_COLOR, "hs_color"]:
-            key = CONST.LED_COLOR
+        if key == CONST.RGB_COLOR:
             if not isinstance(value, (list, tuple)) or not all(
                 isinstance(item, int) for item in value
             ):
@@ -173,6 +199,10 @@ class SkybellDevice:  # pylint:disable=too-many-public-methods, too-many-instanc
 
     async def _async_set_setting(self, settings: dict[str, str | int]) -> None:
         """Validate the settings and then send the PATCH request."""
+        if self.acl == CONST.ACLType.READ.value:
+            raise SkybellAuthenticationException(
+                self, "Attempted setting with invalid scope"
+            )
         for key, value in settings.items():
             _validate_setting(key, value)
 
@@ -181,25 +211,37 @@ class SkybellDevice:  # pylint:disable=too-many-public-methods, too-many-instanc
         except SkybellException:
             _LOGGER.warning("Exception changing settings: %s", settings)
 
+    @property
+    def acl(self) -> str:
+        """Get access level to device."""
+        return self._device_json.get(CONST.ACL, "")
+
+    @property
+    def owner(self) -> bool:
+        """Return if user has admin rights to device."""
+        return self.acl == CONST.ACLType.OWNER.value
+
     @property
     def user_id(self) -> str:
         """Get user id that owns the device."""
         return self._device_json["user"]
 
     @property
-    def mac(self) -> str:
+    def mac(self) -> str | None:
         """Get device mac address."""
-        return self._device_json.get("mac", "")
+        if mac := self._info_json.get("mac"):
+            return cast(str, mac)
+        return None
 
     @property
     def serial_no(self) -> str:
         """Get device serial number."""
-        return self._device_json.get("serialNo", "")
+        return cast(str, self._info_json.get("serialNo", ""))
 
     @property
     def firmware_ver(self) -> str:
         """Get device firmware version."""
-        return self._device_json.get("firmwareVersion", "")
+        return cast(str, self._info_json.get("firmwareVersion", ""))
 
     @property
     def name(self) -> str:
@@ -237,14 +279,9 @@ class SkybellDevice:  # pylint:disable=too-many-public-methods, too-many-instanc
         )
 
     @property
-    def image(self) -> str:
+    def image_url(self) -> str:
         """Get the most recent 'avatar' image."""
-        return self._avatar_json.get(CONST.AVATAR_URL, "")
-
-    @property
-    def activity_image(self) -> str:
-        """Get the most recent activity image."""
-        return self.latest().get(CONST.MEDIA_URL, "")
+        return self._avatar_json.get(CONST.URL, "")
 
     @property
     def wifi_status(self) -> str:
@@ -265,7 +302,9 @@ class SkybellDevice:  # pylint:disable=too-many-public-methods, too-many-instanc
     @property
     def do_not_disturb(self) -> bool:
         """Get if do not disturb is enabled."""
-        return bool(strtobool(str(self._settings_json.get(CONST.DO_NOT_DISTURB))))
+        return bool(
+            strtobool(str(self._settings_json.get(CONST.DO_NOT_DISTURB, "false")))
+        )
 
     @property
     def do_not_ring(self) -> bool:
@@ -275,7 +314,7 @@ class SkybellDevice:  # pylint:disable=too-many-public-methods, too-many-instanc
     @property
     def outdoor_chime_level(self) -> int:
         """Get devices outdoor chime level."""
-        return int(self._settings_json.get(CONST.OUTDOOR_CHIME, ""))
+        return int(self._settings_json.get(CONST.OUTDOOR_CHIME, "0"))
 
     @property
     def outdoor_chime(self) -> bool:
@@ -290,12 +329,12 @@ class SkybellDevice:  # pylint:disable=too-many-public-methods, too-many-instanc
     @property
     def motion_threshold(self) -> int:
         """Get devices motion threshold."""
-        return int(self._settings_json.get(CONST.MOTION_THRESHOLD, ""))
+        return int(self._settings_json.get(CONST.MOTION_THRESHOLD, "0"))
 
     @property
     def video_profile(self) -> int:
         """Get devices video profile."""
-        return int(self._settings_json.get(CONST.VIDEO_PROFILE, ""))
+        return int(self._settings_json.get(CONST.VIDEO_PROFILE, "0"))
 
     @property
     def led_rgb(self) -> tuple[int, int, int]:
@@ -309,7 +348,7 @@ class SkybellDevice:  # pylint:disable=too-many-public-methods, too-many-instanc
     @property
     def led_intensity(self) -> int:
         """Get devices LED intensity."""
-        return int(self._settings_json.get(CONST.BRIGHTNESS, ""))
+        return int(self._settings_json.get(CONST.BRIGHTNESS, "0"))
 
     @property
     def desc(self) -> str:
@@ -324,11 +363,11 @@ def _validate_setting(  # pylint:disable=too-many-branches
 ) -> None:
     """Validate the setting and value."""
     if setting == CONST.DO_NOT_DISTURB:
-        if value not in CONST.DO_NOT_DISTURB_VALUES:
+        if value not in CONST.BOOL_STRINGS:
             raise SkybellException(ERROR.INVALID_SETTING_VALUE, (setting, value))
 
     if setting == CONST.DO_NOT_RING:
-        if value not in CONST.DO_NOT_RING_VALUES:
+        if value not in CONST.BOOL_STRINGS:
             raise SkybellException(ERROR.INVALID_SETTING_VALUE, (setting, value))
 
     if setting == CONST.OUTDOOR_CHIME:
